@@ -521,7 +521,7 @@ public class ServletRequestWrapper implements ServletRequest {
              * Determine scheme from protocol (in the form protocol/majorVersion.minorVersion) and isSecure information
              */
             scheme =
-                new StringBuilder(protocol.substring(0, protocol.indexOf('/')).toLowerCase(Locale.ENGLISH)).append(secure ? "s" : "").toString();
+                new com.openexchange.java.StringAllocator(protocol.substring(0, protocol.indexOf('/')).toLowerCase(Locale.ENGLISH)).append(secure ? "s" : "").toString();
         }
         return scheme;
     }
