@@ -79,9 +79,9 @@ import javax.servlet.http.HttpServletResponse;
 import com.openexchange.ajp13.AJPv13Config;
 import com.openexchange.ajp13.AJPv13RequestHandler;
 import com.openexchange.ajp13.AJPv13Response;
-import com.openexchange.ajp13.AJPv13ServiceRegistry;
 import com.openexchange.ajp13.AJPv13Utility;
 import com.openexchange.ajp13.AjpLongRunningRegistry;
+import com.openexchange.ajp13.Services;
 import com.openexchange.ajp13.coyote.util.ByteChunk;
 import com.openexchange.ajp13.coyote.util.CookieParser;
 import com.openexchange.ajp13.coyote.util.HexUtils;
@@ -337,6 +337,11 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
      */
     private volatile int pingCount;
 
+    /**
+     * The max. idle time
+     */
+    private volatile int max;
+
     /**
      * Whether e secure connection is enforced.
      */
@@ -482,11 +487,12 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
     }
 
     public void startKeepAlivePing() {
-        final TimerService timer = AJPv13ServiceRegistry.getInstance().getService(TimerService.class);
+        final TimerService timer = Services.getService(TimerService.class);
         if (null == timer) {
             throw new IllegalStateException("Missing timer service!");
         }
         final int max = AJPv13Config.getKeepAliveTime();
+        this.max = max;
         scheduledKeepAliveTask =
             timer.scheduleWithFixedDelay(new KeepAliveRunnable(this, max), max, max, TimeUnit.MILLISECONDS);
     }
@@ -761,7 +767,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                     try {
                         output.write(pongMessageArray);
                         lastWriteAccess = System.currentTimeMillis();
-                        // output.flush();
+                        output.flush();
                     } catch (final IOException e) {
                         error = true;
                     } finally {
@@ -1068,7 +1074,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                      */
                     output.write(flushMessageArray);
                     lastWriteAccess = System.currentTimeMillis();
-                    // output.flush();
+                    output.flush();
                 } catch (final IOException e) {
                     // Set error flag
                     error = true;
@@ -1082,6 +1088,13 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                 final Lock hardLock = mainLock.writeLock();
                 hardLock.lock();
                 try {
+                    /*
+                     * Ensure we still exceed max. idle time and are not yet finished
+                     */
+                    final int max = this.max;
+                    if (finished || (max <= 0) || (!isProcessing() || ((System.currentTimeMillis() - getLastWriteAccess()) <= max))) {
+                        return;
+                    }
                     boolean doReadMessage = true;
                     if (response.isCommitted()) {
                         /*
@@ -1089,7 +1102,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                          */
                         output.write(flushMessageArray);
                         lastWriteAccess = System.currentTimeMillis();
-                        // output.flush();
+                        output.flush();
                         if (DEBUG) {
                             LOG.debug("Performed keep-alive through a flush package.");
                         }
@@ -1098,8 +1111,8 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                          * Not committed, yet. Write an empty GET-BODY-CHUNK package.
                          */
                         output.write(AJPv13Response.getGetBodyChunkBytes(0));
-                        output.flush();
                         lastWriteAccess = System.currentTimeMillis();
+                        output.flush();
                         /*
                          * Receive probably empty body chunk
                          */
@@ -2059,11 +2072,11 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
         softLock.lock();
         try {
             sink.writeTo(output);
-            // output.flush();
+            lastWriteAccess = System.currentTimeMillis();
+            output.flush();
         } finally {
             softLock.unlock();
         }
-        lastWriteAccess = System.currentTimeMillis();
     }
 
     private static final int getNumOfCookieHeader(final List<List<String>> formattedCookies) {
@@ -2119,11 +2132,11 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
         softLock.lock();
         try {
             output.write(reuse ? endMessageArray : endMessageArrayNoReuse);
-            // output.flush();
+            lastWriteAccess = System.currentTimeMillis();
+            output.flush();
         } finally {
             softLock.unlock();
         }
-        lastWriteAccess = System.currentTimeMillis();
     }
 
     /**
@@ -2184,11 +2197,11 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
         softLock.lock();
         try {
             output.write(getBodyMessageArray);
-            // output.flush();
+            lastWriteAccess = System.currentTimeMillis();
+            output.flush();
         } finally {
             softLock.unlock();
         }
-        lastWriteAccess = System.currentTimeMillis();
 
         final boolean moreData = receive();
         if (!moreData) {
@@ -2337,18 +2350,18 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                 len -= thisTime;
                 softLock.lock();
                 try {
-                    output.write(getSendBodyChunkBytes(b, start + off, thisTime));
-                    // output.flush();
+                    writeSendBodyChunkBytes(b, start + off, thisTime);
+                    lastWriteAccess = System.currentTimeMillis();
+                    output.flush();
                 } finally {
                     softLock.unlock();
                 }
                 off += thisTime;
             } while (len > 0);
-            lastWriteAccess = System.currentTimeMillis();
             return chunk.getLength();
         }
 
-        private byte[] getSendBodyChunkBytes(final byte[] b, final int off, final int len) {
+        private void writeSendBodyChunkBytes(final byte[] b, final int off, final int len) throws IOException {
             /*
              * prefix + chunk_length (2 bytes) + chunk bytes + terminating zero byte
              */
@@ -2366,7 +2379,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
             sink.write(len & 0xFF);
             sink.write(b, off, len);
             sink.write(0);
-            return sink.toByteArray();
+            sink.writeTo(output);
         }
 
     }
